==> ordering-core-0.3.2.tgz: package/lib/esm/orderTypes.js <==
export var EOrderType;
(function (EOrderType) {
    EOrderType["TAKE_AWAY"] = "TAKE_AWAY";
    EOrderType["DELIVERY"] = "DELIVERY";
    EOrderType["DINE_IN"] = "DINE_IN";
    EOrderType["DINE_IN_OPEN"] = "DINE_IN_OPEN";
    EOrderType["GLOVO_DELIVERY"] = "GLOVO_DELIVERY";
    EOrderType["GLOVO_TAKE_AWAY"] = "GLOVO_TAKE_AWAY";
    EOrderType["JUSTEAT_DELIVERY"] = "JUSTEAT_DELIVERY";
    EOrderType["JUSTEAT_TAKE_AWAY"] = "JUSTEAT_TAKE_AWAY";
})(EOrderType || (EOrderType = {}));
// https://docs.orderingstack.com/order/
export var EOrderStatus;
(function (EOrderStatus) {
    EOrderStatus["NEW"] = "NEW";
    EOrderStatus["COMPLETED"] = "COMPLETED";
    EOrderStatus["VERIFIED"] = "VERIFIED";
    EOrderStatus["DELIVER"] = "DELIVER";
    EOrderStatus["DELIVERED"] = "DELIVERED";
    EOrderStatus["CLOSED"] = "CLOSED";
    EOrderStatus["ABANDONED"] = "ABANDONED";
    EOrderStatus["CANCELLED"] = "CANCELLED";
    EOrderStatus["PICKED_UP"] = "PICKED_UP";
})(EOrderStatus || (EOrderStatus = {}));
export var EOrderLineStatus;
(function (EOrderLineStatus) {
    EOrderLineStatus["NEW"] = "NEW";
    EOrderLineStatus["TECHNICAL"] = "TECHNICAL";
    EOrderLineStatus["CONFIRMED"] = "CONFIRMED";
    EOrderLineStatus["PROCESSING"] = "PROCESSING";
    EOrderLineStatus["PROCESSED"] = "PROCESSED";
    EOrderLineStatus["VOID"] = "VOID";
    EOrderLineStatus["WASTE"] = "WASTE";
})(EOrderLineStatus || (EOrderLineStatus = {}));
export var EOrderPaymentType;
(function (EOrderPaymentType) {
    EOrderPaymentType["CASH"] = "CASH";
    EOrderPaymentType["CARD"] = "CARD";
    EOrderPaymentType["COD"] = "COD";
    EOrderPaymentType["TERMINAL"] = "TERMINAL";
    EOrderPaymentType["EPAYMENT"] = "EPAYMENT";
    EOrderPaymentType["COUPON"] = "COUPON";
    EOrderPaymentType["WALLET"] = "WALLET";
    EOrderPaymentType["PREAUTHORIZED"] = "PREAUTHORIZED";
    EOrderPaymentType["RETURN"] = "RETURN";
    EOrderPaymentType["EXTERNAL"] = "EXTERNAL";
})(EOrderPaymentType || (EOrderPaymentType = {}));
export var EOrderSource;
(function (EOrderSource) {
    EOrderSource["KIOSK"] = "KIOSK";
    EOrderSource["WEB"] = "WEB";
    EOrderSource["JUST_EAT_TAKE_AWAY"] = "JUSTEATTAKEAWAY";
    EOrderSource["GLOVO"] = "GLOVO";
    EOrderSource["PYSZNE"] = "PYSZNE";
    EOrderSource["WOLT"] = "WOLT";
    EOrderSource["UBER"] = "UBER";
})(EOrderSource || (EOrderSource = {}));
export var EOrderProductKind;
(function (EOrderProductKind) {
    EOrderProductKind["GROUP"] = "group";
    EOrderProductKind["PRODUCT"] = "product";
})(EOrderProductKind || (EOrderProductKind = {}));
;
export var EOrderRecStatus;
(function (EOrderRecStatus) {
    EOrderRecStatus[EOrderRecStatus["INITIALIZING"] = 0] = "INITIALIZING";
    EOrderRecStatus[EOrderRecStatus["INVALID"] = 1] = "INVALID";
    EOrderRecStatus[EOrderRecStatus["VALID"] = 2] = "VALID";
})(EOrderRecStatus || (EOrderRecStatus = {}));

==> ordering-core-0.3.3.tgz: package/lib/esm/orderTypes.js <==
export var EOrderType;
(function (EOrderType) {
    EOrderType["TAKE_AWAY"] = "TAKE_AWAY";
    EOrderType["DELIVERY"] = "DELIVERY";
    EOrderType["DINE_IN"] = "DINE_IN";
    EOrderType["DINE_IN_OPEN"] = "DINE_IN_OPEN";
    EOrderType["GLOVO_DELIVERY"] = "GLOVO_DELIVERY";
    EOrderType["GLOVO_TAKE_AWAY"] = "GLOVO_TAKE_AWAY";
    EOrderType["JUSTEAT_DELIVERY"] = "JUSTEAT_DELIVERY";
    EOrderType["JUSTEAT_TAKE_AWAY"] = "JUSTEAT_TAKE_AWAY";
})(EOrderType || (EOrderType = {}));
// https://docs.orderingstack.com/order/
export var EOrderStatus;
(function (EOrderStatus) {
    EOrderStatus["NEW"] = "NEW";
    EOrderStatus["COMPLETED"] = "COMPLETED";
    EOrderStatus["VERIFIED"] = "VERIFIED";
    EOrderStatus["DELIVER"] = "DELIVER";
    EOrderStatus["DELIVERED"] = "DELIVERED";
    EOrderStatus["CLOSED"] = "CLOSED";
    EOrderStatus["ABANDONED"] = "ABANDONED";
    EOrderStatus["CANCELLED"] = "CANCELLED";
    EOrderStatus["PICKED"] = "PICKED";
})(EOrderStatus || (EOrderStatus = {}));
export var EOrderLineStatus;
(function (EOrderLineStatus) {
    EOrderLineStatus["NEW"] = "NEW";
    EOrderLineStatus["TECHNICAL"] = "TECHNICAL";
    EOrderLineStatus["CONFIRMED"] = "CONFIRMED";
    EOrderLineStatus["PROCESSING"] = "PROCESSING";
    EOrderLineStatus["PROCESSED"] = "PROCESSED";
    EOrderLineStatus["VOID"] = "VOID";
    EOrderLineStatus["WASTE"] = "WASTE";
})(EOrderLineStatus || (EOrderLineStatus = {}));
export var EOrderPaymentType;
(function (EOrderPaymentType) {
    EOrderPaymentType["CASH"] = "CASH";
    EOrderPaymentType["CARD"] = "CARD";
    EOrderPaymentType["COD"] = "COD";
    EOrderPaymentType["TERMINAL"] = "TERMINAL";
    EOrderPaymentType["EPAYMENT"] = "EPAYMENT";
    EOrderPaymentType["COUPON"] = "COUPON";
    EOrderPaymentType["WALLET"] = "WALLET";
    EOrderPaymentType["PREAUTHORIZED"] = "PREAUTHORIZED";
    EOrderPaymentType["RETURN"] = "RETURN";
    EOrderPaymentType["EXTERNAL"] = "EXTERNAL";
})(EOrderPaymentType || (EOrderPaymentType = {}));
export var EOrderSource;
(function (EOrderSource) {
    EOrderSource["KIOSK"] = "KIOSK";
    EOrderSource["WEB"] = "WEB";
    EOrderSource["JUST_EAT_TAKE_AWAY"] = "JUSTEATTAKEAWAY";
    EOrderSource["GLOVO"] = "GLOVO";
    EOrderSource["PYSZNE"] = "PYSZNE";
    EOrderSource["WOLT"] = "WOLT";
    EOrderSource["UBER"] = "UBER";
})(EOrderSource || (EOrderSource = {}));
export var EOrderProductKind;
(function (EOrderProductKind) {
    EOrderProductKind["GROUP"] = "group";
    EOrderProductKind["PRODUCT"] = "product";
})(EOrderProductKind || (EOrderProductKind = {}));
;
export var EOrderRecStatus;
(function (EOrderRecStatus) {
    EOrderRecStatus[EOrderRecStatus["INITIALIZING"] = 0] = "INITIALIZING";
    EOrderRecStatus[EOrderRecStatus["INVALID"] = 1] = "INVALID";
    EOrderRecStatus[EOrderRecStatus["VALID"] = 2] = "VALID";
})(EOrderRecStatus || (EOrderRecStatus = {}));
